"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

var _beginTransaction = _interopRequireDefault(require("./begin-transaction"));

var _commitTransaction = _interopRequireDefault(require("./commit-transaction"));

var _rollbackTransaction = _interopRequireDefault(require("./rollback-transaction"));

var _isTimeoutError = _interopRequireDefault(require("./is-timeout-error"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, specific) => {
  const log = (0, _getLog.default)('connect');
  log.debug('configuring RDS data service client');
  const {
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    executeStatement,
    coercer
  } = specific;
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = pool.config;
  eventsTableName = pool.coerceEmptyString(eventsTableName, 'events');
  snapshotsTableName = pool.coerceEmptyString(snapshotsTableName, 'snapshots');
  secretsTableName = pool.coerceEmptyString(secretsTableName, 'default');
  databaseName = pool.coerceEmptyString(databaseName);
  const {
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    ...rdsConfig
  } = connectionOptions;

  if (dbClusterOrInstanceArn == null || awsSecretStoreArn == null) {
    throw new Error(`Options "dbClusterOrInstanceArn" and "awsSecretStoreArn" are mandatory`);
  }

  const rdsDataService = new RDSDataService(rdsConfig);
  Object.assign(pool, {
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    databaseName,
    eventsTableName,
    secretsTableName,
    snapshotsTableName,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    beginTransaction: _beginTransaction.default,
    commitTransaction: _commitTransaction.default,
    rollbackTransaction: _rollbackTransaction.default,
    escapeId,
    escape,
    isTimeoutError: _isTimeoutError.default
  });
  log.debug('RDS data service client configured');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map