"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

const loadSnapshot = async (pool, snapshotKey) => {
  const {
    databaseName,
    snapshotsTableName,
    executeStatement,
    escapeId,
    escape,
    isTimeoutError
  } = pool;

  if (snapshotKey == null || snapshotKey.constructor !== String) {
    throw new Error('Snapshot key must be string');
  }

  const databaseNameAsId = escapeId(databaseName);
  const snapshotsTableNameAsId = escapeId(snapshotsTableName);
  let result = null;

  for (let index = 0;; index++) {
    let rows = null;

    while (true) {
      try {
        rows = await executeStatement(`SELECT substring(
            "snapshotContent" 
            FROM ${index * _constants.LOAD_CHUNK_SIZE + 1}
            FOR ${_constants.LOAD_CHUNK_SIZE}
          ) AS "SnapshotContentChunk"
          FROM ${databaseNameAsId}.${snapshotsTableNameAsId}
          WHERE "snapshotKey" = ${escape(snapshotKey)} 
          LIMIT 1`);
        break;
      } catch (err) {
        if (isTimeoutError(err)) {
          continue;
        }

        throw err;
      }
    }

    const content = rows.length > 0 ? rows[0].SnapshotContentChunk : null;

    if (content == null) {
      break;
    } else if (content != null && result == null) {
      result = '';
    }

    result += content;

    if (content.length < _constants.LOAD_CHUNK_SIZE) {
      break;
    }
  }

  return result;
};

var _default = loadSnapshot;
exports.default = _default;
//# sourceMappingURL=load-snapshot.js.map